referrerpolicy=no-referrer-when-downgrade

OverseerSubsystemContext

Struct OverseerSubsystemContext 

pub struct OverseerSubsystemContext<M: AssociateOutgoing + Send + 'static> { /* private fields */ }
A context type that is given to the Subsystem upon spawning. It can be used by Subsystem to communicate with other Subsystems or to spawn it’s SubsystemJobs.